from honeypots import QDNSServer, QFTPServer, QHTTPProxyServer, QHTTPSServer, QHTTPServer, QIMAPServer, QMysqlServer, QPOP3Server, QPostgresServer, QRedisServer, QSMBServer, QSMTPServer, QSOCKS5Server, QSSHServer, QTelnetServer, QVNCServer, clean_all
from time import sleep

print("Testing QDNSServer")
qdnsserver = QDNSServer()
qdnsserver.run_server(process=True, auto=True)
sleep(1)
qdnsserver.test_server()
qdnsserver.kill_server()
clean_all()

print("Testing QFTPServer")
qftpserver = QFTPServer()
qftpserver.run_server(process=True, auto=True)
sleep(1)
qftpserver.test_server()
qftpserver.kill_server()
clean_all()

print("Testing QHTTPProxyServer")
qhttpproxyserver = QHTTPProxyServer()
qhttpproxyserver.run_server(process=True, auto=True)
sleep(1)
qhttpproxyserver.test_server()
qhttpproxyserver.kill_server()
clean_all()

print("Testing QHTTPServer")
qhttpserver = QHTTPServer()
qhttpserver.run_server(process=True, auto=True)
sleep(1)
qhttpserver.test_server()
qhttpserver.kill_server()
clean_all()

print("Testing QHTTPSServer")
qhttpsserver = QHTTPSServer()
qhttpsserver.run_server(process=True, auto=True)
sleep(1)
qhttpsserver.test_server()
qhttpsserver.kill_server()
clean_all()

print("Testing QIMAPServer")
qimapserver = QIMAPServer()
qimapserver.run_server(process=True, auto=True)
sleep(1)
qimapserver.test_server()
qimapserver.kill_server()
clean_all()

print("Testing QMysqlServer")
qmysqlserver = QMysqlServer()
qmysqlserver.run_server(process=True, auto=True)
sleep(1)
qmysqlserver.test_server()
qmysqlserver.kill_server()
clean_all()

print("Testing QTPOP3Server")
qpop3server = QPOP3Server()
qpop3server.run_server(process=True, auto=True)
sleep(1)
qpop3server.test_server()
qpop3server.kill_server()
clean_all()

print("Testing QPostgresServer")
qpostgresserver = QPostgresServer()
qpostgresserver.run_server(process=True, auto=True)
sleep(1)
qpostgresserver.test_server()
qpostgresserver.kill_server()
clean_all()

print("Testing QRedisServer")
qredisserver = QRedisServer()
qredisserver.run_server(process=True, auto=True)
sleep(1)
qredisserver.test_server()
qredisserver.kill_server()
clean_all()

print("Testing QSMBServer")
qsmbserver = QSMBServer()
qsmbserver.run_server(process=True, auto=True)
sleep(1)
qsmbserver.test_server()
qsmbserver.kill_server()
clean_all()

print("Testing QSMTPServer")
qsmtpserver = QSMTPServer()
qsmtpserver.run_server(process=True, auto=True)
sleep(1)
qsmtpserver.test_server()
qsmtpserver.kill_server()
clean_all()

print("Testing QSOCKS5Server")
qsocks5server = QSOCKS5Server()
qsocks5server.run_server(process=True, auto=True)
sleep(1)
qsocks5server.test_server()
qsocks5server.kill_server()
clean_all()

print("Testing QSSHServer")
qsshserver = QSSHServer()
qsshserver.run_server(process=True, auto=True)
sleep(1)
qsshserver.test_server()
qsshserver.kill_server()
clean_all()

print("Testing QTelnetServer")
qtelnetserver = QTelnetServer()
qtelnetserver.run_server(process=True, auto=True)
sleep(1)
qtelnetserver.test_server()
qtelnetserver.kill_server()
clean_all()

print("Testing QVNCServer")
qvncserver = QVNCServer()
qvncserver.run_server(process=True, auto=True)
sleep(1)
qvncserver.test_server()
qvncserver.kill_server()
clean_all()



"""
//  -------------------------------------------------------------
//  author        Giga
//  project       qeeqbox/honeypots
//  email         gigaqeeq@gmail.com
//  description   app.py (CLI)
//  licensee      AGPL-3.0
//  -------------------------------------------------------------
//  contributors list qeeqbox/social-analyzer/graphs/contributors
//  -------------------------------------------------------------
"""

from warnings import filterwarnings
filterwarnings(action='ignore', module='.*OpenSSL.*')

from twisted.internet.protocol import Protocol, Factory
from twisted.internet import reactor
from redis import StrictRedis
from twisted.python import log as tlog
from subprocess import Popen
from os import path
from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger
from uuid import uuid4


class QRedisServer():
    def __init__(self, ip=None, port=None, username=None, password=None, mocking=False, config=''):
        self.ip = ip or '0.0.0.0'
        self.port = port or 6379
        self.username = username or "test"
        self.password = password or "test"
        self.mocking = mocking or ''
        self.process = None
        self.uuid = 'honeypotslogger' + '_' + __class__.__name__ + '_' + str(uuid4())[:8]
        self.config = config
        if config:
            self.logs = setup_logger(self.uuid, config)
        else:
            self.logs = setup_logger(self.uuid, None)
        disable_logger(1, tlog)

    def redis_server_main(self):
        _q_s = self

        class CustomRedisProtocol(Protocol):

            def get_command(self, data):
                try:
                    _data = data.decode('utf-8').split('\x0d\x0a')
                    if _data[0][0] == "*":
                        _count = int(_data[0][1]) - 1
                        _data.pop(0)
                        if _data[0::2][0][0] == "$" and len(_data[1::2][0]) == int(_data[0::2][0][1]):
                            return _count, _data[1::2][0]
                except Exception as e:
                    print(e)

                return 0, ""

            def parse_data(self, c, data):
                _data = data.decode('utf-8').split('\r\n')[3::]
                user, password = "", ""
                if c == 2:
                    _ = 0
                    if _data[0::2][_][0] == "$" and len(_data[1::2][_]) == int(_data[0::2][_][1]):
                        user = (_data[1::2][_])
                    _ = 1
                    if _data[0::2][_][0] == "$" and len(_data[1::2][_]) == int(_data[0::2][_][1]):
                        password = (_data[1::2][_])
                if c == 1:
                    _ = 0
                    if _data[0::2][_][0] == "$" and len(_data[1::2][_]) == int(_data[0::2][_][1]):
                        password = (_data[1::2][_])
                if c == 2 or c == 1:
                    if user == _q_s.username and password == _q_s.password:
                        _q_s.logs.info(["servers", {'server': 'redis_server', 'action': 'login', 'status': 'success', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': _q_s.username, 'password': _q_s.password}])
                    else:
                        _q_s.logs.info(["servers", {'server': 'redis_server', 'action': 'login', 'status': 'failed', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': user, 'password': password}])

            def connectionMade(self):
                self._state = 1
                self._variables = {}
                _q_s.logs.info(["servers", {'server': 'redis_server', 'action': 'connection', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port}])

            def dataReceived(self, data):
                c, command = self.get_command(data)
                if command == "AUTH":
                    self.parse_data(c, data)
                    self.transport.write(b"-ERR invalid password\r\n")
                else:
                    self.transport.write(b"-ERR unknown command '{}'\r\n".format(command))
                self.transport.loseConnection()

        factory = Factory()
        factory.protocol = CustomRedisProtocol
        reactor.listenTCP(port=self.port, factory=factory, interface=self.ip)
        reactor.run()

    def run_server(self, process=False, auto=False):
        if process:
            if auto:
                port = get_free_port()
                if port > 0:
                    self.port = port
                    self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--username', str(self.username), '--password', str(self.password), '--mocking', str(self.mocking), '--config', str(self.config), '--uuid', str(self.uuid)])
                    if self.process.poll() is None:
                        self.logs.info(["servers", {'server': 'redis_server', 'action': 'process', 'status': 'success', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
                    else:
                        self.logs.info(["servers", {'server': 'redis_server', 'action': 'process', 'status': 'error', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
                else:
                    self.logs.info(["servers", {'server': 'redis_server', 'action': 'setup', 'status': 'error', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
            elif self.close_port() and self.kill_server():
                self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--username', str(self.username), '--password', str(self.password), '--mocking', str(self.mocking), '--config', str(self.config), '--uuid', str(self.uuid)])
                if self.process.poll() is None:
                    self.logs.info(["servers", {'server': 'redis_server', 'action': 'process', 'status': 'success', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
                else:
                    self.logs.info(["servers", {'server': 'redis_server', 'action': 'process', 'status': 'error', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
        else:
            self.redis_server_main()

    def test_server(self, ip=None, port=None, username=None, password=None):
        try:
            _ip = ip or self.ip
            _port = port or self.port
            _username = username or self.username
            _password = password or self.password
            r = StrictRedis.from_url('redis://{}:{}@{}:{}/1'.format(_username, _password, _ip, _port))
            for key in r.scan_iter("user:*"):
                pass
        except BaseException:
            pass

    def close_port(self):
        ret = close_port_wrapper('redis_server', self.ip, self.port, self.logs)
        return ret

    def kill_server(self):
        ret = kill_server_wrapper('redis_server', self.uuid, self.process)
        return ret


if __name__ == '__main__':
    parsed = server_arguments()
    if parsed.docker or parsed.aws or parsed.custom:
        qredisserver = QRedisServer(ip=parsed.ip, port=parsed.port, username=parsed.username, password=parsed.password, mocking=parsed.mocking, config=parsed.config)
        qredisserver.run_server()



"""
//  -------------------------------------------------------------
//  author        Giga
//  project       qeeqbox/honeypots
//  email         gigaqeeq@gmail.com
//  description   app.py (CLI)
//  licensee      AGPL-3.0
//  -------------------------------------------------------------
//  contributors list qeeqbox/social-analyzer/graphs/contributors
//  -------------------------------------------------------------
"""

from twisted.mail.imap4 import IMAP4Server
from twisted.internet.protocol import Factory
from twisted.internet import reactor
from random import choice
from twisted import cred
from imaplib import IMAP4
from subprocess import Popen
from os import path
from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger
from uuid import uuid4


class QIMAPServer():
    def __init__(self, ip=None, port=None, username=None, password=None, mocking=False, config=''):
        self.ip = ip or '0.0.0.0'
        self.port = port or 143
        self.username = username or "test"
        self.password = password or "test"
        self.mocking = mocking or ''
        self.random_servers = [b'OK Microsoft Exchange Server 2003 IMAP4rev1 server version 6.5.6944.0 DC9 ready']
        self.process = None
        self.uuid = 'honeypotslogger' + '_' + __class__.__name__ + '_' + str(uuid4())[:8]
        self.config = config
        if config:
            self.logs = setup_logger(self.uuid, config)
        else:
            self.logs = setup_logger(self.uuid, None)

    def imap_server_main(self):

        _q_s = self

        class CustomIMAP4Server(IMAP4Server):

            def connectionMade(self):
                _q_s.logs.info(["servers", {'server': 'imap_server', 'action': 'connection', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port}])

                if isinstance(_q_s.mocking, bool):
                    if _q_s.mocking == True:
                        self.sendPositiveResponse(message=choice(_q_s.random_servers))
                elif isinstance(_q_s.mocking, str):
                    self.sendPositiveResponse(message=choice(_q_s.random_servers))
                else:
                    self.sendPositiveResponse(message=b'Welcome')

            def authenticateLogin(self, user, passwd):
                if user == _q_s.username and passwd == _q_s.password:
                    _q_s.logs.info(["servers", {'server': 'imap_server', 'action': 'login', 'status': 'success', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': _q_s.username, 'password': _q_s.password}])
                else:
                    _q_s.logs.info(["servers", {'server': 'imap_server', 'action': 'login', 'status': 'failed', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': user, 'password': passwd}])

                raise cred.error.UnauthorizedLogin()

            def lineReceived(self, line):
                try:
                    _line = line.split(b" ")[1]
                    if _line.lower().startswith(b"login") or _line.lower().startswith(b"capability"):
                        IMAP4Server.lineReceived(self, line)
                except BaseException:
                    pass

        class CustomIMAPFactory(Factory):
            protocol = CustomIMAP4Server
            portal = None

            def buildProtocol(self, address):
                p = self.protocol()
                p.portal = self.portal
                p.factory = self
                return p

        factory = CustomIMAPFactory()
        reactor.listenTCP(port=self.port, factory=factory, interface=self.ip)
        reactor.run()

    def run_server(self, process=False, auto=False):
        if process:
            if auto:
                port = get_free_port()
                if port > 0:
                    self.port = port
                    self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--username', str(self.username), '--password', str(self.password), '--mocking', str(self.mocking), '--config', str(self.config), '--uuid', str(self.uuid)])
                    if self.process.poll() is None:
                        self.logs.info(["servers", {'server': 'imap_server', 'action': 'process', 'status': 'success', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
                    else:
                        self.logs.info(["servers", {'server': 'imap_server', 'action': 'process', 'status': 'error', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
                else:
                    self.logs.info(["servers", {'server': 'imap_server', 'action': 'setup', 'status': 'error', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
            elif self.close_port() and self.kill_server():
                self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--username', str(self.username), '--password', str(self.password), '--mocking', str(self.mocking), '--config', str(self.config), '--uuid', str(self.uuid)])
                if self.process.poll() is None:
                    self.logs.info(["servers", {'server': 'imap_server', 'action': 'process', 'status': 'success', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
                else:
                    self.logs.info(["servers", {'server': 'imap_server', 'action': 'process', 'status': 'error', 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
        else:
            self.imap_server_main()

    def test_server(self, ip=None, port=None, username=None, password=None):
        try:
            _ip = ip or self.ip
            _port = port or self.port
            _username = username or self.username
            _password = password or self.password
            imap_test = IMAP4(_ip, _port)
            imap_test.login(_username, _password)
        except BaseException:
            pass

    def close_port(self):
        ret = close_port_wrapper('imap_server', self.ip, self.port, self.logs)
        return ret

    def kill_server(self):
        ret = kill_server_wrapper('imap_server', self.uuid, self.process)
        return ret


if __name__ == '__main__':
    parsed = server_arguments()
    if parsed.docker or parsed.aws or parsed.custom:
        qimapserver = QIMAPServer(ip=parsed.ip, port=parsed.port, username=parsed.username, password=parsed.password, mocking=parsed.mocking, config=parsed.config)
        qimapserver.run_server()



__G__ = "(G)bd249ce4"

from argparse import ArgumentParser


def server_arguments():
    _server_parser = ArgumentParser(prog="Server")
    _server_parsergroupdeq = _server_parser.add_argument_group('Initialize Server')
    _server_parsergroupdeq.add_argument('--ip', type=str, help="Change server ip, current is 0.0.0.0", required=False, metavar='')
    _server_parsergroupdeq.add_argument('--port', type=int, help="Change port", required=False, metavar='')
    _server_parsergroupdeq.add_argument('--username', type=str, help="Change username", required=False, metavar='')
    _server_parsergroupdeq.add_argument('--password', type=str, help="Change password", required=False, metavar='')
    _server_parsergroupdeq.add_argument('--resolver_addresses', type=str, help="Change resolver address", required=False, metavar='')
    _server_parsergroupdeq.add_argument('--domain', type=str, help="A domain to test", required=False, metavar='')
    _server_parsergroupdeq.add_argument('--mocking', type=str, help="Random banner", required=False)
    _server_parsergroupdes = _server_parser.add_argument_group('Sinffer options')
    _server_parsergroupdes.add_argument('--filter', type=str, help="setup the Sinffer filter", required=False)
    _server_parsergroupdes.add_argument('--interface', type=str, help="sinffer interface E.g eth0", required=False)
    _server_parsergroupdef = _server_parser.add_argument_group('Initialize Loging')
    _server_parsergroupdef.add_argument('--logs', type=str, help="db, terminal or all ", required=False)
    _server_parsergroupdea = _server_parser.add_argument_group('Auto Configuration')
    _server_parsergroupdea.add_argument('--docker', action='store_true', help="Run project in docker", required=False)
    _server_parsergroupdea.add_argument('--aws', action='store_true', help="Run project in aws", required=False)
    _server_parsergroupdea.add_argument('--test', action='store_true', help="Test current server", required=False)
    _server_parsergroupdea.add_argument('--custom', action='store_true', help="Run custom server", required=False)
    return _server_parser.parse_args()



from setuptools import setup

with open("README.rst", "r") as fh:
    long_description = fh.read()

setup(
    name='honeypots',
    author='QeeqBox',
    author_email='gigaqeeq@gmail.com',
    description="Easy to setup honeypots!",
    long_description=long_description,
    version='0.16',
    license="AGPL-3.0",
    url="https://github.com/qeeqbox/honeypots",
    packages=['honeypots'],
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "honeypots = honeypots.__main__:main"
        ]
    },
    install_requires=[
        'pipenv',
        'twisted',
        'psutil',
        'psycopg2-binary',
        'dnspython',
        'requests',
        'impacket',
        'paramiko==2.7.1',
        'redis',
        'mysql-connector',
        'pycryptodome',
        'vncdotool',
        'service_identity',
        'requests[socks]',
        'pygments',
        'scapy',
        'netifaces'
    ],
    python_requires='>=3'
)



#!/usr/bin/env python

from warnings import filterwarnings
filterwarnings(action='ignore', module='.*OpenSSL.*')

from honeypots import QDNSServer, QFTPServer, QHTTPProxyServer, QHTTPServer, QHTTPSServer, QIMAPServer, QMysqlServer, QPOP3Server, QPostgresServer, QRedisServer, QSMBServer, QSMTPServer, QSOCKS5Server, QSSHServer, QTelnetServer, QVNCServer, server_arguments, clean_all, postgres_class, setup_logger, QBSniffer, get_running_servers
from time import sleep
from atexit import register
from argparse import ArgumentParser
from sys import stdout
from subprocess import Popen
from netifaces import ifaddresses, AF_INET, AF_LINK
from psutil import Process, net_io_counters
from uuid import uuid4
from json import JSONEncoder, dumps, load


all_servers = ['QDNSServer', 'QFTPServer', 'QHTTPProxyServer', 'QHTTPServer', 'QHTTPSServer', 'QIMAPServer', 'QMysqlServer', 'QPOP3Server', 'QPostgresServer', 'QRedisServer', 'QSMBServer', 'QSMTPServer', 'QSOCKS5Server', 'QSSHServer', 'QTelnetServer', 'QVNCServer']

temp_honeypots = []


def exit_handler():
    print("Cleaning")
    clean_all()
    sleep(1)


def list_all_honeypots():
    for honeypot in all_servers:
        print(honeypot[1:].replace('Server', '').lower())


def msg():
    '''
    welcome message
    '''
    return """\npython3 -m honeypots --setup all\npython3 -m honeypots --setup ssh --logs all --logs_location /tmp/honeypots_logs\n"""


ARG_PARSER = ArgumentParser(description="Qeeqbox/honeypots customizable honeypots for monitoring network traffic, bots activities, and username\\password credentials", usage=msg())
ARG_PARSER.add_argument("--setup", help="target honeypot E.g. ssh or you can have multiple E.g ssh,http,https", metavar="", default="")
ARG_PARSER.add_argument("--list", action="store_true", help="list all available honeypots")
ARG_PARSER.add_argument("--kill", action="store_true", help="kill all honeypots")
ARG_PARSER.add_argument("--chameleon", action="store_true", help="reserved for chameleon project")
ARG_PARSER.add_argument("--config", help="config file for logs and database", metavar="", default="")
ARGV = ARG_PARSER.parse_args()

if __name__ == "__main__":
    if ARGV.list:
        list_all_honeypots()
    elif ARGV.kill:
        clean_all()
    elif ARGV.chameleon and ARGV.config and ARGV.config != '':
        port = None
        interface = None
        honeypots = None
        with open(ARGV.config) as f:
            config_data = load(f)
            port = config_data['port']
            interface = config_data['interface']
            honeypots = config_data['honeypots']
        if port and interface:
            print('Your IP: {}'.format(ifaddresses(interface)[AF_INET][0]['addr']))
            print('Your MAC: {}'.format(ifaddresses(interface)[AF_LINK][0]['addr']))
            Popen('iptables -A OUTPUT -p tcp -m tcp --tcp-flags RST RST -j DROP', shell=True)
            print('Wait for 10 seconds..')
            stdout.flush()
            sleep(2)
            uuid = 'honeypotslogger' + '_' + 'main' + '_' + str(uuid4())[:8]
            logs = setup_logger(uuid, ARGV.config, True)
            servers = []
            if honeypots:
                for server in honeypots.split(','):
                    if ":" in server:
                        for honeypot in all_servers:
                            if 'q{}server'.format(server.split(':')[0]).lower() == honeypot.lower():
                                x = globals()[honeypot](port=int(server.split(':')[1]), config=ARGV.config)
                                x.run_server(process=True)
                                temp_honeypots.append(x)
                    else:
                        for honeypot in all_servers:
                            if 'q{}server'.format(server).lower() == honeypot.lower():
                                x = globals()[honeypot](config=ARGV.config)
                                x.run_server(process=True)
                                temp_honeypots.append(x)
            else:
                for honeypot in all_servers:
                    x = globals()[honeypot](config=ARGV.config)
                    x.run_server(process=True)
                    temp_honeypots.append(x)

            x = globals()['QBSniffer'](filter='not port {}'.format(port), interface=interface, config=ARGV.config)
            x.run_sniffer(process=True)
            temp_honeypots.append(x)
            while True:
                try:
                    _servers = {}
                    logs.info(['system', {'type': 'network', 'bytes_sent': net_io_counters().bytes_sent, 'bytes_recv': net_io_counters().bytes_recv, 'packets_sent': net_io_counters().packets_sent, 'packets_recv': net_io_counters().packets_recv}])
                    for server in temp_honeypots:
                        _servers[server.__class__.__name__] = {'memory': Process(server.process.pid).memory_percent(), 'cpu': Process(server.process.pid).cpu_percent()}
                    logs.info(['system', _servers])
                except Exception as e:
                    pass
                sleep(20)
    elif ARGV.setup != "":
        print("Use [Enter] to exit or python3 -m honeypots --kill")
        register(exit_handler)
        if ARGV.setup == "all":
            for honeypot in all_servers:
                x = globals()[honeypot](config=ARGV.config)
                x.run_server(process=True, auto=True)
                temp_honeypots.append(x)
        else:
            servers = ARGV.setup.split(',')
            for server in servers:
                if ":" in server:
                    for honeypot in all_servers:
                        if 'q{}server'.format(server.split(':')[0]).lower() == honeypot.lower():
                            x = globals()[honeypot](port=int(server.split(':')[1]), config=ARGV.config)
                            x.run_server(process=True)
                            temp_honeypots.append(x)
                else:
                    for honeypot in all_servers:
                        if 'q{}server'.format(server).lower() == honeypot.lower():
                            x = globals()[honeypot](config=ARGV.config)
                            x.run_server(process=True, auto=True)
                            temp_honeypots.append(x)
        if len(temp_honeypots) > 0:
            input("")
            for server in temp_honeypots:
                try:
                    print("Killing {}".format(server.__class__.__name__))
                    server.kill_server()
                except BaseException:
                    pass
            print("Please wait few seconds")
            sleep(5)
